@@ -485,13 +485,30 @@ window_removed (AtkObject *atk_obj,
                  AtkObject *child)
 {
   GtkWidget *widget;
+  GtkWindow *window;
 
   g_return_if_fail (GAIL_IS_WINDOW (child));
 
   widget = GTK_ACCESSIBLE (child)->widget;
   g_return_if_fail (widget);
 
-  g_signal_handlers_disconnect_by_func (widget, (GCallback) window_focus, NULL);
+  window = GTK_WINDOW (widget);
+  /*
+   * Deactivate window if it is still focused and we are removing it. This
+   * can happen when a dialog displayed by gok is removed.
+   */
+  if (window->is_active &&
+      window->has_toplevel_focus)
+    {
+      gchar *signal_name;
+      AtkObject *atk_obj;
+
+      atk_obj = gtk_widget_get_accessible (widget);
+      signal_name =  "deactivate";
+      g_signal_emit (atk_obj, g_signal_lookup (signal_name, GAIL_TYPE_WINDOW), 0); 
+    }
+
+  g_signal_handlers_disconnect_by_func (widget, (gpointer) window_focus, NULL);
   g_signal_emit (child, g_signal_lookup ("destroy", GAIL_TYPE_WINDOW), 0); 
 }
 
@@ -502,7 +519,7 @@ window_focus (GtkWidget     *widget,
   gchar *signal_name;
   AtkObject *atk_obj;
 
-  g_return_val_if_fail (GTK_WIDGET (widget), FALSE);
+  g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
   atk_obj = gtk_widget_get_accessible (widget);
   signal_name =  (event->in) ? "activate" : "deactivate";
